summaryrefslogtreecommitdiff
path: root/lib/omb.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
committerEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
commitc8b8f07af14ad2ce9d0c0267962dd3bbf6473a4b (patch)
tree2ed665ca0639c845f425c671fdffccc01e6ddc3a /lib/omb.php
parentd0baab6978f1959382d568d26cc9f8f552a7b764 (diff)
change Laconica and Control Yourself to StatusNet in PHP files
Diffstat (limited to 'lib/omb.php')
-rw-r--r--lib/omb.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/omb.php b/lib/omb.php
index 4f6a96095..6179ca140 100644
--- a/lib/omb.php
+++ b/lib/omb.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2008, 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -66,7 +66,7 @@ function omb_oauth_datastore()
{
static $store = null;
if (!$store) {
- $store = new LaconicaOAuthDataStore();
+ $store = new StatusNetOAuthDataStore();
}
return $store;
}
@@ -202,7 +202,7 @@ function omb_post_notice_keys($notice, $postnoticeurl, $tk, $secret)
$result = $fetcher->post($req->get_normalized_http_url(),
$req->to_postdata(),
- array('User-Agent: Laconica/' . LACONICA_VERSION));
+ array('User-Agent: StatusNet/' . LACONICA_VERSION));
if ($result->status == 403) { # not authorized, don't send again
common_debug('403 result, deleting subscription', __FILE__);
@@ -282,7 +282,7 @@ function omb_update_profile($profile, $remote_profile, $subscription)
$result = $fetcher->post($req->get_normalized_http_url(),
$req->to_postdata(),
- array('User-Agent: Laconica/' . LACONICA_VERSION));
+ array('User-Agent: StatusNet/' . LACONICA_VERSION));
if (empty($result) || !$result) {
common_debug("Unable to contact " . $req->get_normalized_http_url());
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, Control Yourself, Inc.
+ * StatusNet - a distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify